==> certmanager-model-v1alpha3-6.7.2-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/IssuerListBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IssuerListBuilder extends IssuerListFluentImpl<IssuerListBuilder> implements VisitableBuilder<IssuerList,IssuerListBuilder>{
  public IssuerListBuilder() {
    this(false);
  }
  public IssuerListBuilder(Boolean validationEnabled) {
    this(new IssuerList(), validationEnabled);
  }
  public IssuerListBuilder(IssuerListFluent<?> fluent) {
    this(fluent, false);
  }
  public IssuerListBuilder(IssuerListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IssuerList(), validationEnabled);
  }
  public IssuerListBuilder(IssuerListFluent<?> fluent,IssuerList instance) {
    this(fluent, instance, false);
  }
  public IssuerListBuilder(IssuerListFluent<?> fluent,IssuerList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IssuerListBuilder(IssuerList instance) {
    this(instance,false);
  }
  public IssuerListBuilder(IssuerList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  IssuerListFluent<?> fluent;
  Boolean validationEnabled;
  public IssuerList build() {
    IssuerList buildable = new IssuerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha3/IssuerListBuilder.java <==
package io.fabric8.certmanager.api.model.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IssuerListBuilder extends IssuerListFluent<IssuerListBuilder> implements VisitableBuilder<IssuerList,IssuerListBuilder>{
  public IssuerListBuilder() {
    this(false);
  }
  public IssuerListBuilder(Boolean validationEnabled) {
    this(new IssuerList(), validationEnabled);
  }
  public IssuerListBuilder(IssuerListFluent<?> fluent) {
    this(fluent, false);
  }
  public IssuerListBuilder(IssuerListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IssuerList(), validationEnabled);
  }
  public IssuerListBuilder(IssuerListFluent<?> fluent,IssuerList instance) {
    this(fluent, instance, false);
  }
  public IssuerListBuilder(IssuerListFluent<?> fluent,IssuerList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new IssuerList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IssuerListBuilder(IssuerList instance) {
    this(instance,false);
  }
  public IssuerListBuilder(IssuerList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new IssuerList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  IssuerListFluent<?> fluent;
  Boolean validationEnabled;
  public IssuerList build() {
    IssuerList buildable = new IssuerList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}
